=======
Credits
=======

Development Lead
----------------

* Carmen Bianca Bakker <carmenbbakker@gmail.com>

Contributors
------------

* Robin C. Thomas <rc.thomas90@gmail.com> - Code snippets from ck2launcher
